aboutsummaryrefslogtreecommitdiff
path: root/gcc/config/i960
diff options
context:
space:
mode:
authorKazu Hirata <kazu@cs.umass.edu>2002-09-19 13:51:24 +0000
committerKazu Hirata <kazu@gcc.gnu.org>2002-09-19 13:51:24 +0000
commit9cd10576c58786afe2ec3a9193f85f61de760068 (patch)
treeccfaa90cab6055a4c2d86909f94576ffc123b5ce /gcc/config/i960
parentfff08fd8dad02e4b83e37555da6acd2693ae3db7 (diff)
downloadgcc-9cd10576c58786afe2ec3a9193f85f61de760068.zip
gcc-9cd10576c58786afe2ec3a9193f85f61de760068.tar.gz
gcc-9cd10576c58786afe2ec3a9193f85f61de760068.tar.bz2
fp-bit.c: Follow spelling conventions.
* config/fp-bit.c: Follow spelling conventions. * config/d30v/d30v.c: Likewise. * config/d30v/d30v.h: Likewise. * config/fr30/fr30.c: Likewise. * config/fr30/fr30.h: Likewise. * config/fr30/fr30.md: Likewise. * config/frv/frv.c: Likewise. * config/frv/frv.h: Likewise. * config/h8300/h8300.c: Likewise. * config/h8300/lib1funcs.asm: Likewise. * config/i370/i370.c: Likewise. * config/i386/i386.h: Likewise. * config/i386/i386.md: Likewise. * config/i386/pentium.md: Likewise. * config/i386/winnt.c: Likewise. * config/i960/i960.c: Likewise. * config/ia64/ia64.h: Likewise. * config/ip2k/ip2k.c: Likewise. * config/ip2k/ip2k.h: Likewise. * config/ip2k/ip2k.md: Likewise. * config/ip2k/libgcc.S: Likewise. From-SVN: r57303
Diffstat (limited to 'gcc/config/i960')
-rw-r--r--gcc/config/i960/i960.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/config/i960/i960.c b/gcc/config/i960/i960.c
index ae85711..7ebbb9e 100644
--- a/gcc/config/i960/i960.c
+++ b/gcc/config/i960/i960.c
@@ -321,8 +321,8 @@ bitpos (val)
return -1;
}
-/* Return non-zero if OP is a mask, i.e. all one bits are consecutive.
- The return value indicates how many consecutive non-zero bits exist
+/* Return nonzero if OP is a mask, i.e. all one bits are consecutive.
+ The return value indicates how many consecutive nonzero bits exist
if this is a mask. This is the same as the next function, except that
it does not indicate what the start and stop bit positions are. */